@@ -157,7 +157,7 @@ async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
     result = dict(result=True, comment=[], ret=None)
 
     # Create an instance resource object to use for defaults
-    instance = hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
+    instance = await hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
 
     # Verify that the instance is in a state with all the right permissions
     if not instance.state["Name"] == "running":
@@ -336,7 +336,7 @@ async def connect(
     result = dict(result=True, comment=[], ret={})
 
     # Create an instance resource object to use for defaults
-    instance = hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
+    instance = await hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
 
     # Use the availability zone defined in the instance if none was provided
     if availability_zone is None:
@@ -451,7 +451,7 @@ async def start(hub, ctx, instance_id: str):
     if not ret.result:
         return False
 
-    resource = hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
+    resource = await hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
     await hub.tool.boto3.resource.exec(ctx, resource, "wait_until_running")
 
     return result
@@ -471,7 +471,7 @@ async def stop(hub, ctx, instance_id: str):
     if not ret.result:
         return False
 
-    resource = hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
+    resource = await hub.tool.boto3.resource.create(ctx, "ec2", "Instance", instance_id)
     await hub.tool.boto3.resource.exec(ctx, resource, "wait_until_stopped")
 
     return result
