@@ -1,15 +1,56 @@
 import copy
 from typing import Any
 from typing import Dict
-from typing import List
+
+__func_alias__ = {"list_": "list"}
+
+
+async def get(hub, ctx, name: str, resource_id: str = None):
+    """
+    Get an IAM role from AWS. Provide role name as input
+
+    Args:
+        name(string): An Idem name of the IAM role. Idem will use this as the role name if resource_id is not specified.
+        resource_id(string, optional): AWS IAM role name.
+
+    """
+    result = dict(comment=[], ret=None, result=True)
+    before = await hub.exec.boto3.client.iam.get_role(
+        ctx, RoleName=resource_id if resource_id else name
+    )
+    if not before["result"]:
+        if "NoSuchEntity" in str(before["comment"]):
+            result["comment"].append(
+                hub.tool.aws.comment_utils.get_empty_comment(
+                    resource_type="aws.iam.role", name=name
+                )
+            )
+            result["comment"] += list(before["comment"])
+            return result
+        result["result"] = False
+        result["comment"] = before["comment"]
+        return result
+    before_tag = await hub.exec.boto3.client.iam.list_role_tags(
+        ctx, RoleName=resource_id if resource_id else name
+    )
+    if not before_tag["result"]:
+        result["result"] = False
+        result["comment"] = before_tag["comment"]
+        return result
+    if before["ret"].get("Role"):
+        before["ret"]["Role"]["Tags"] = before_tag["ret"].get("Tags", [])
+        result["ret"] = hub.tool.aws.iam.conversion_utils.convert_raw_role_to_present(
+            raw_resource=before["ret"]["Role"]
+        )
+    return result
 
 
 async def update_role_tags(
     hub,
     ctx,
     role_name: str,
-    old_tags: List[Dict[str, Any]],
-    new_tags: List[Dict[str, Any]],
+    old_tags: Dict[str, Any],
+    new_tags: Dict[str, Any],
 ) -> Dict[str, Any]:
     """
     Update tags of AWS IAM Role
@@ -19,48 +60,51 @@ async def update_role_tags(
         ctx: A dict with the keys/values for the execution of the Idem run located in
         `hub.idem.RUNS[ctx['run_name']]`.
         role_name: AWS IAM role name
-        old_tags: list of old tags
-        new_tags: list of new tags
+        old_tags: dict of old tags
+        new_tags: dict of new tags
 
     Returns:
-        {"result": True|False, "comment": Tuple, "ret": Dict}
+        {"result": True|False, "comment": Tuple, "ret": Dict of updated tags}
     """
-    tags_to_add = []
-    old_tags_map = {tag.get("Key"): tag for tag in old_tags}
-    tags_result = copy.deepcopy(old_tags_map)
-    for tag in new_tags:
-        if tag.get("Key") in old_tags_map:
-            if tag.get("Value") == old_tags_map.get(tag.get("Key")).get("Value"):
-                del old_tags_map[tag.get("Key")]
-            else:
-                tags_to_add.append(tag)
-        else:
-            tags_to_add.append(tag)
-    tags_to_remove = [tag.get("Key") for tag in old_tags_map.values()]
+    tags_to_add = {}
+    tags_to_remove = {}
+    if new_tags is not None:
+        tags_to_remove, tags_to_add = hub.tool.aws.tag_utils.diff_tags_dict(
+            old_tags=old_tags, new_tags=new_tags
+        )
     result = dict(comment=(), result=True, ret=None)
     if (not tags_to_remove) and (not tags_to_add):
+        result["ret"] = copy.deepcopy(old_tags if old_tags else {})
         return result
     if tags_to_remove:
         if not ctx.get("test", False):
             delete_ret = await hub.exec.boto3.client.iam.untag_role(
-                ctx, RoleName=role_name, TagKeys=tags_to_remove
+                ctx, RoleName=role_name, TagKeys=list(tags_to_remove.keys())
             )
             if not delete_ret["result"]:
                 result["comment"] = delete_ret["comment"]
                 result["result"] = False
                 return result
-        [tags_result.pop(key) for key in tags_to_remove]
     if tags_to_add:
         if not ctx.get("test", False):
             add_ret = await hub.exec.boto3.client.iam.tag_role(
-                ctx, RoleName=role_name, Tags=tags_to_add
+                ctx,
+                RoleName=role_name,
+                Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags=tags_to_add),
             )
             if not add_ret["result"]:
                 result["comment"] = add_ret["comment"]
                 result["result"] = False
                 return result
-    result["ret"] = {"tags": list(tags_result.values()) + tags_to_add}
-    result["comment"] = (f"Update tags: Add [{tags_to_add}] Remove [{tags_to_remove}]",)
+    result["ret"] = new_tags
+    if ctx.get("test", False):
+        result["comment"] = hub.tool.aws.comment_utils.would_update_tags_comment(
+            tags_to_remove=tags_to_remove, tags_to_add=tags_to_add
+        )
+    else:
+        result["comment"] = hub.tool.aws.comment_utils.update_tags_comment(
+            tags_to_remove=tags_to_remove, tags_to_add=tags_to_add
+        )
     return result
 
 
@@ -140,6 +184,7 @@ async def update_policy(
             result["result"] = False
             return result
 
+    result["ret"] = policy
     if ctx.get("test", False):
         result["comment"] = (f"Would update aws.iam.role '{role_name}' policy",)
     else:
