@@ -1,15 +1,14 @@
 import copy
 from typing import Any
 from typing import Dict
-from typing import List
 
 
 async def update_rds_tags(
     hub,
     ctx,
     resource_arn,
-    old_tags: List[Dict[str, Any]],
-    new_tags: List[Dict[str, Any]],
+    old_tags: Dict[str, Any],
+    new_tags: Dict[str, Any],
 ):
     """
     Update tags of AWS RDS resources
@@ -18,50 +17,46 @@ async def update_rds_tags(
         hub:
         ctx:
         resource_arn: aws resource arn
-        old_tags: list of old tags
-        new_tags: list of new tags
+        old_tags (Dict): Dict in the format of {tag-key: tag-value}
+        new_tags (Dict): Dict in the format of {tag-key: tag-value}
 
     Returns:
-        {"result": True|False, "comment": "A message", "ret": None}
+        {"result": True|False, "comment": "A message", "ret": dict of updated tags}
 
     """
-    tags_to_add = []
-    tags_to_remove = []
-    old_tags_map = {tag.get("Key"): tag for tag in old_tags or []}
-    tags_result = copy.deepcopy(old_tags_map)
+    tags_to_add = {}
+    tags_to_remove = {}
     if new_tags is not None:
-        for tag in new_tags:
-            if tag.get("Key") in old_tags_map:
-                if tag.get("Value") == old_tags_map.get(tag.get("Key")).get("Value"):
-                    del old_tags_map[tag.get("Key")]
-                else:
-                    tags_to_add.append(tag)
-            else:
-                tags_to_add.append(tag)
-        tags_to_remove = list(old_tags_map.keys())
+        tags_to_remove, tags_to_add = hub.tool.aws.tag_utils.diff_tags_dict(
+            old_tags=old_tags, new_tags=new_tags
+        )
     result = dict(comment=(), result=True, ret=None)
     if (not tags_to_remove) and (not tags_to_add):
+        result["ret"] = copy.deepcopy(old_tags if old_tags else {})
         return result
     if tags_to_remove:
         if not ctx.get("test", False):
             delete_ret = await hub.exec.boto3.client.rds.remove_tags_from_resource(
-                ctx, ResourceName=resource_arn, TagKeys=tags_to_remove
+                ctx,
+                ResourceName=resource_arn,
+                TagKeys=list(tags_to_remove),
             )
             if not delete_ret["result"]:
                 result["comment"] = delete_ret["comment"]
                 result["result"] = False
                 return result
-        [tags_result.pop(key) for key in tags_to_remove]
     if tags_to_add:
         if not ctx.get("test", False):
             add_ret = await hub.exec.boto3.client.rds.add_tags_to_resource(
-                ctx, ResourceName=resource_arn, Tags=tags_to_add
+                ctx,
+                ResourceName=resource_arn,
+                Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags_to_add),
             )
             if not add_ret["result"]:
                 result["comment"] = add_ret["comment"]
                 result["result"] = False
                 return result
-    result["ret"] = {"tags": list(tags_result.values()) + tags_to_add}
+    result["ret"] = new_tags
     result["comment"] = result["comment"] + (
         f"Update tags: Add [{tags_to_add}] Remove [{tags_to_remove}]",
     )
