@@ -22,8 +22,33 @@ async def update_topic_attributes(
 
     """
     result = dict(comment=(), result=True, ret=None)
-    attributes_diff = differ.deep_diff(old_attributes, new_attributes)
-    attributes_to_update = attributes_diff.get("new")
+    json_attributes = [
+        "DeliveryPolicy",
+        "Policy",
+    ]
+    attributes_to_update = {}
+    for key, value in new_attributes.items():
+        if key in old_attributes:
+            if key in json_attributes:
+                # standardise json strings and check if they are identical else add to update dictionary
+                old_value_standardised = (
+                    hub.tool.aws.state_comparison_utils.standardise_json(
+                        old_attributes.get(key)
+                    )
+                )
+                value_standardised = (
+                    hub.tool.aws.state_comparison_utils.standardise_json(value)
+                )
+                if not hub.tool.aws.state_comparison_utils.is_json_identical(
+                    old_value_standardised, value_standardised
+                ):
+                    attributes_to_update[key] = value
+            else:
+                # check if other string attributes are equal else add to update dictionary
+                if old_attributes.get(key) != value:
+                    attributes_to_update[key] = value
+        else:
+            attributes_to_update[key] = value
 
     if attributes_to_update:
         if ctx.get("test", False):
