@@ -7,6 +7,14 @@ from typing import Dict
 
 __contracts__ = ["resource"]
 
+TREQ = {
+    "present": {
+        "require": [
+            "aws.ec2.subnet.present",
+        ],
+    },
+}
+
 
 async def present(
     hub,
@@ -95,7 +103,7 @@ async def present(
     if before:
         result[
             "old_state"
-        ] = await hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+        ] = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
             ctx,
             raw_resource=before["ret"]["DeliveryChannels"][0],
             idem_resource_name=name,
@@ -116,6 +124,9 @@ async def present(
             sns_topic_arn=sns_topic_arn,
             config_snapshot_delivery_properties=update_config_snapshot_delivery_properties,
         )
+        result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
+            "aws.config.delivery_channel", name
+        )
 
         if update_payload["ret"]:
             resource_updated = True
@@ -128,14 +139,14 @@ async def present(
                     result["result"] = False
                     return result
 
-                result["comment"] = (f"Updated aws.config.delivery_channel '{name}'",)
+                result["comment"] = hub.tool.aws.comment_utils.update_comment(
+                    "aws.config.delivery_channel", name
+                )
                 result["result"] = update_ret["result"]
             else:
                 for key, value in update_payload["ret"].items():
                     plan_state[key] = value
 
-        if not result["result"]:
-            result["comment"] = result["comment"] + (f"{name} already exists",)
     else:
         delivery_props = {}
         dc_payload = {"name": name, "s3BucketName": s3_bucket_name}
@@ -151,10 +162,16 @@ async def present(
             ]
             dc_payload["configSnapshotDeliveryProperties"] = delivery_props
         if ctx.get("test", False):
-            result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
-                enforced_state={}, desired_state=dc_payload
+            result[
+                "new_state"
+            ] = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+                ctx,
+                raw_resource=dc_payload,
+                idem_resource_name=name,
+            )
+            result["comment"] = hub.tool.aws.comment_utils.would_create_comment(
+                "aws.config.delivery_channel", name
             )
-            result["comment"] = (f"Would create aws.config.delivery_channel '{name}'",)
             return result
 
         ret = await hub.exec.boto3.client.config.put_delivery_channel(
@@ -165,23 +182,29 @@ async def present(
             result["comment"] = ret["comment"] + ret["comment"]
             return result
             # resource_id = name
-        result["comment"] = result["comment"] + (
-            f"Created aws.config.delivery_channel '{name}'",
+        result["comment"] = hub.tool.aws.comment_utils.create_comment(
+            "aws.config.delivery_channel", name
         )
 
     if ctx.get("test", False):
-        result["new_state"] = plan_state
-        if not resource_updated:
-            result["comment"] = f"Would create aws.config.delivery_channel '{name}'"
-        else:
-            result["comment"] = (f"Would update aws.config.delivery_channel '{name}'",)
+        result[
+            "new_state"
+        ] = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+            ctx,
+            raw_resource=plan_state,
+            idem_resource_name=name,
+        )
+        if resource_updated:
+            result["comment"] = hub.tool.aws.comment_utils.would_update_comment(
+                "aws.config.delivery_channel", name
+            )
     elif (not before) or resource_updated:
         after = await hub.exec.boto3.client.config.describe_delivery_channels(
             ctx, DeliveryChannelNames=[resource_id]
         )
         result[
             "new_state"
-        ] = await hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+        ] = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
             ctx,
             raw_resource=after["ret"]["DeliveryChannels"][0],
             idem_resource_name=name,
@@ -235,7 +258,7 @@ async def absent(
     elif ctx.get("test", False):
         result[
             "old_state"
-        ] = await hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+        ] = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
             ctx,
             raw_resource=before["ret"]["DeliveryChannels"][0],
             idem_resource_name=resource_id,
@@ -248,7 +271,7 @@ async def absent(
         try:
             result[
                 "old_state"
-            ] = await hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+            ] = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
                 ctx,
                 raw_resource=before["ret"]["DeliveryChannels"][0],
                 idem_resource_name=resource_id,
@@ -291,7 +314,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
 
     for resource in ret["ret"]["DeliveryChannels"]:
         resource_id = resource.get("name")
-        resource_translated = await hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
+        resource_translated = hub.tool.aws.config.conversion_utils.convert_raw_config_delivery_channel_to_present(
             ctx, raw_resource=resource, idem_resource_name=resource_id
         )
         result[resource_id] = {
