@@ -4,7 +4,7 @@ hub.exec.boto3.client.dynamodb.delete_table
 hub.exec.boto3.client.dynamodb.describe_table
 hub.exec.boto3.client.dynamodb.list_tables
 hub.exec.boto3.client.dynamodb.update_table
-resource = hub.tool.boto3.resource.create(ctx, "dynamodb", "Table", name)
+resource = await hub.tool.boto3.resource.create(ctx, "dynamodb", "Table", name)
 hub.tool.boto3.resource.exec(resource, delete, *args, **kwargs)
 hub.tool.boto3.resource.exec(resource, delete_item, *args, **kwargs)
 hub.tool.boto3.resource.exec(resource, get_item, *args, **kwargs)
@@ -21,6 +21,8 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+__contracts__ = ["resource"]
+
 
 async def present(
     hub,
