@@ -29,12 +29,10 @@ async def present(
     rejected. If you create a VPC peering connection request between VPCs with overlapping CIDR blocks, the VPC
     peering connection has a status of failed.
 
-    NOTE: These five parameters - peer_owner_id, peer_vpc_id, vpc_id, peer_region and status
+    NOTE: These parameters - peer_owner_id, peer_vpc_id, vpc_id, peer_region
     can't be updated for a given VPC peering connection.
-    The only thing that could be updated is the tags,
-    and when status is set to active when a new resource is created in real,
-    an attempt will be made to set the vpc peering connection status to active.
-    In case of an update attempt of the previously mentioned five parameters,
+    Only tags and status can be updated for a VPC peering connection
+    In case of an update attempt of the previously mentioned four parameters,
     where resource_id is passed for an existing connection, they will be ignored.
 
     Args:
@@ -66,7 +64,8 @@ async def present(
             Each tag consists of a key name and an associated value. Defaults to None.
 
         status: (str, Optional)
-            The current status of the vpc peering connection.
+            The desired status for the VPC peering connection, but in practice,
+            an update will be attempted only if this status is set to "active".
 
     Request Syntax:
        .. code-block:: sls
@@ -119,7 +118,7 @@ async def present(
 
         # Update tags
         if tags is not None and tags != result["old_state"].get("tags"):
-            update_ret = await hub.exec.aws.ec2.tag.update_tags(
+            update_ret = await hub.tool.aws.ec2.tag.update_tags(
                 ctx=ctx,
                 resource_id=resource_id,
                 old_tags=result["old_state"].get("tags"),
@@ -127,7 +126,7 @@ async def present(
             )
 
             result["result"] = update_ret["result"]
-            result["comment"] = update_ret["comment"]
+            result["comment"] += update_ret["comment"]
             if not update_ret["result"]:
                 return result
 
@@ -135,6 +134,30 @@ async def present(
             if update_ret["ret"] is not None and ctx.get("test", False):
                 plan_state["tags"] = update_ret["ret"]
 
+        # Update status - activate the connection
+        # The only update possible is status activation - accepting the connection.
+        # All the other statuses a connection could have are changed on their own,
+        # for example: failed, expired, rejected...
+        # The deleted status could be set by calling the absent function on this resource.
+        if status == "active" and status != result["old_state"].get("status"):
+            accept_ret = await hub.tool.aws.ec2.vpc_peering_connection_utils.activate_vpc_peering_connection(
+                ctx,
+                "aws.ec2.vpc_peering_connection",
+                name,
+                resource_id,
+                result["old_state"].get("status"),
+                status,
+            )
+
+            result["result"] = accept_ret["result"]
+            result["comment"] += accept_ret["comment"]
+            if not accept_ret["result"]:
+                return result
+
+            resource_updated = resource_updated or bool(accept_ret["ret"])
+            if accept_ret["ret"] is not None and ctx.get("test", False):
+                plan_state["status"] = accept_ret["ret"]["connection_status"]
+
         if resource_updated:
             if ctx.get("test", False):
                 result["comment"] += hub.tool.aws.comment_utils.would_update_comment(
@@ -145,11 +168,12 @@ async def present(
                     "aws.ec2.vpc_peering_connection", name
                 )
         else:
-            result["comment"] = hub.tool.aws.comment_utils.already_exists_comment(
+            result["comment"] += hub.tool.aws.comment_utils.already_exists_comment(
                 "aws.ec2.vpc_peering_connection", name
             )
     else:
         if ctx.get("test", False):
+            desired_status = status or "pending-acceptance"
             result["new_state"] = hub.tool.aws.test_state_utils.generate_test_state(
                 enforced_state={},
                 desired_state={
@@ -159,13 +183,21 @@ async def present(
                     "vpc_id": vpc_id,
                     "peer_region": peer_region,
                     "tags": tags,
-                    "status": status,
+                    "status": desired_status,
                 },
             )
 
-            result["comment"] = hub.tool.aws.comment_utils.would_create_comment(
+            result["comment"] += hub.tool.aws.comment_utils.would_create_comment(
                 "aws.ec2.vpc_peering_connection", name
             )
+
+            if status == "active":
+                result[
+                    "comment"
+                ] += hub.tool.aws.comment_utils.would_update_status_comment(
+                    "aws.ec2.vpc_peering_connection", name, resource_id, status
+                )
+
             return result
 
         tag_specifications = [
@@ -175,7 +207,7 @@ async def present(
             }
         ]
 
-        ret = await hub.exec.boto3.client.ec2.create_vpc_peering_connection(
+        create_ret = await hub.exec.boto3.client.ec2.create_vpc_peering_connection(
             ctx,
             **{
                 "PeerOwnerId": peer_owner_id,
@@ -186,38 +218,35 @@ async def present(
             },
         )
 
-        result["new_state"] = {"name": name, "resource_id": resource_id}
-        result["result"] = ret["result"]
+        result["result"] = create_ret["result"]
         if not result["result"]:
-            result["comment"] += ret["comment"]
+            result["comment"] += create_ret["comment"]
             return result
 
-        result["comment"] = hub.tool.aws.comment_utils.create_comment(
+        result["comment"] += hub.tool.aws.comment_utils.create_comment(
             "aws.ec2.vpc_peering_connection", name
         )
 
-        new_vpc_peering_connection = ret["ret"]["VpcPeeringConnection"]
+        new_vpc_peering_connection = create_ret["ret"]["VpcPeeringConnection"]
         resource_id = new_vpc_peering_connection["VpcPeeringConnectionId"]
 
+        # The only status change possible is status activation - accepting the connection.
+        # All the other statuses a connection could have are changed on their own,
+        # for example: failed, expired, rejected...
+        # The deleted status could be set by calling the absent function on this resource.
         if status == "active":
-            accept_ret = await hub.exec.boto3.client.ec2.accept_vpc_peering_connection(
-                ctx, VpcPeeringConnectionId=resource_id
+            accept_ret = await hub.tool.aws.ec2.vpc_peering_connection_utils.activate_vpc_peering_connection(
+                ctx,
+                "aws.ec2.vpc_peering_connection",
+                name,
+                resource_id,
+                new_vpc_peering_connection["Status"]["Code"],
+                status,
             )
 
+            result["comment"] += accept_ret["comment"]
+            result["result"] = accept_ret["result"]
             if not accept_ret["result"]:
-                result["comment"] += accept_ret["comment"]
-                result["result"] = False
-                return result
-
-            new_status = accept_ret["ret"]["VpcPeeringConnection"]["Status"]["Code"]
-            result[
-                "comment"
-            ] += hub.tool.aws.comment_utils.resource_status_updated_comment(
-                "aws.ec2.vpc_peering_connection", name, new_status
-            )
-
-            if not accept_ret["result"]:
-                result["result"] = False
                 return result
 
     if ctx.get("test", False):
@@ -228,7 +257,7 @@ async def present(
         )
         if not after["result"]:
             result["result"] = False
-            result["comment"] = after["comment"]
+            result["comment"] += after["comment"]
             return result
 
         result["new_state"] = copy.deepcopy(after["ret"])
