@@ -1,4 +1,6 @@
 import copy
+from dataclasses import field
+from dataclasses import make_dataclass
 from typing import Any
 from typing import Dict
 from typing import List
@@ -15,7 +17,13 @@ async def present(
     thumbprint_list: List,
     resource_id: str = None,
     client_id_list: List = None,
-    tags: List = None,
+    tags: Dict[str, Any]
+    or List[
+        make_dataclass(
+            "Tag",
+            [("Key", str, field(default=None)), ("Value", str, field(default=None))],
+        )
+    ] = None,
 ) -> Dict[str, Any]:
     r"""
     Creates an IAM entity to describe an identity provider (IdP) that supports OpenID Connect (OIDC).
@@ -84,24 +92,18 @@ async def present(
             There is no defined format for a client ID. The CreateOpenIDConnectProviderRequest operation accepts
             client IDs up to 255 characters long.
 
-        tags(List, optional): A list of tags that you want to attach to the new IAM OpenID Connect (OIDC) provider.
-            Each tag consists of a key name and an associated value. For more information about tagging, see Tagging
-            IAM resources in the IAM User Guide .
-
-            (dict) --
-                A structure that represents user-provided metadata that can be associated with an IAM resource.
-                For more information about tagging, see Tagging IAM resources in the IAM User Guide .
-
-                Key (string)
-                The key name that can be used to look up or retrieve the associated value. For example, Department or
-                Cost Center are common choices.
-
-                Value (string)
-                The value associated with this tag. For example, tags with a key name of Department could have values
-                such as Human Resources , Accounting , and Support . Tags with a key name of Cost Center might have
-                values that consist of the number associated with the different cost centers in your company. Typically,
-                 many resources have tags with the same key name but with different values.
-
+        tags(Dict or List, optional): Dict in the format of {tag-key: tag-value} or List of tags in the format of
+            [{"Key": tag-key, "Value": tag-value}] to associate with the IAM OpenID Connect (OIDC) provider.
+            Each tag consists of a key name and an associated value. Defaults to None.
+            * (Key): The key name that can be used to look up or retrieve the associated value. For example,
+                Department or Cost Center are common choices.
+            * (Value): The value associated with this tag. For example, tags with a key name of Department could have
+                values such as Human Resources, Accounting, and Support. Tags with a key name of Cost Center
+                might have values that consist of the number associated with the different cost centers in your
+                company. Typically, many resources have tags with the same key name but with different values.
+                Amazon Web Services always interprets the tag Value as a single string. If you need to store an
+                array, you can store comma-separated values in the string. However, you must interpret the value
+                in your code.
     Request Syntax:
         [oidc-resource-name]:
           aws.iam.open_id_connect_provider.present:
@@ -143,6 +145,8 @@ async def present(
     before = None
     resource_updated = False
     plan_state = None
+    if isinstance(tags, List):
+        tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(tags)
 
     if resource_id:
         response = await hub.exec.boto3.client.iam.get_open_id_connect_provider(
@@ -209,7 +213,7 @@ async def present(
                     return result
 
             # update tags
-            if tags is not None:
+            if tags is not None and tags != result["old_state"].get("tags"):
                 update_ret = (
                     await hub.exec.aws.iam.open_id_connect_provider.update_tags(
                         ctx=ctx,
@@ -220,9 +224,9 @@ async def present(
                 )
                 result["comment"] = result["comment"] + update_ret["comment"]
                 result["result"] = result["result"] and update_ret["result"]
-                resource_updated = resource_updated or bool(update_ret["ret"])
+                resource_updated = resource_updated or bool(update_ret["result"])
                 if ctx.get("test", False) and update_ret["ret"] is not None:
-                    plan_state["tags"] = update_ret["ret"].get("tags")
+                    plan_state["tags"] = update_ret["ret"]
                 if not result["result"]:
                     return result
         except hub.tool.boto3.exception.ClientError as e:
@@ -251,7 +255,9 @@ async def present(
                 Url=url,
                 ClientIDList=client_id_list,
                 ThumbprintList=thumbprint_list,
-                Tags=tags,
+                Tags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags)
+                if tags
+                else None,
             )
             result["result"] = ret["result"]
             if not result["result"]:
