@@ -1,3 +1,4 @@
+"""State module for managing IAM Role Policy Attachments."""
 import copy
 from typing import Any
 from typing import Dict
@@ -8,33 +9,39 @@ __contracts__ = ["resource"]
 async def present(
     hub, ctx, name: str, role_name: str, policy_arn: str, resource_id: str = None
 ) -> Dict[str, Any]:
-    """
-    Attaches the specified managed policy to the specified IAM role. When you attach a managed policy to a role,
-     the managed policy becomes part of the role's permission (access) policy.
+    """Attaches the specified managed policy to the specified IAM role.
+
+    When you attach a managed policy to a role, the managed policy becomes part of the role's permission (access) policy.
 
     Args:
-        hub:
-        ctx:
-        name(Text): A name to represent the operation. This name is only for logging purpose. It is not used to
-         attach a policy to a role.
-        role_name(Text): The name (friendly name, not ARN) of the role to attach a policy.
-         This parameter allows (through its regex pattern ) a string of characters consisting of upper and lowercase
-          alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
-        policy_arn(Text): The Amazon Resource Name (ARN) of the IAM policy you want to attach.
-        resource_id(Text, Optional): The identifier for this object
+        name(str):
+            A name to represent the operation. This name is only for logging purpose. It is not used to attach a policy
+            to a role.
+
+        role_name(str):
+            The name (friendly name, not ARN) of the role to attach a policy. This parameter allows (through its regex pattern )
+            a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also
+            include any of the following characters: _+=,.@-
+
+        policy_arn(str):
+            The Amazon Resource Name (ARN) of the IAM policy you want to attach.
+
+        resource_id(str, Optional):
+            The identifier for this object
 
     Request Syntax:
-        [iam-attach-role-policy-name]:
-          aws.iam.role_policy_attachment.present:
-          - resource_id: 'string'
-          - role_name: 'string'
-          - policy_arn: 'string'
+        .. code-block:: sls
+
+            [iam-attach-role-policy-name]:
+              aws.iam.role_policy_attachment.present:
+                - resource_id: 'string'
+                - role_name: 'string'
+                - policy_arn: 'string'
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
             idem-test-policy-temp-name:
@@ -46,7 +53,7 @@ async def present(
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     try:
         before_ret = (
-            await hub.exec.aws.iam.role_policy_attachment.is_role_policy_attached(
+            await hub.tool.aws.iam.role_policy_attachment.is_role_policy_attached(
                 ctx, role_name=role_name, policy_arn=policy_arn
             )
         )
@@ -109,22 +116,33 @@ async def present(
 async def absent(
     hub, ctx, name: str, role_name: str, policy_arn: str
 ) -> Dict[str, Any]:
-    """
-
-    Removes the specified managed policy from the specified role.
+    """Removes the specified managed policy from the specified role.
 
     Args:
-        name(Text): The name of the AWS IAM role policy.
-        role_name(Text): The name (friendly name, not ARN) of the role to attach a policy.
-         This parameter allows (through its regex pattern ) a string of characters consisting of upper and lowercase
-          alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-
-        policy_arn(Text): The Amazon Resource Name (ARN) of the IAM policy you want to attach.
+        name(str):
+            The name of the AWS IAM role policy.
+
+        role_name(str):
+            The name (friendly name, not ARN) of the role to attach a policy. This parameter allows (through its regex pattern )
+            a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also
+            include any of the following characters: _+=,.@-
+
+        policy_arn(str):
+            The Amazon Resource Name (ARN) of the IAM policy you want to attach.
+
+    Request Syntax:
+        .. code-block:: sls
+
+            [rpa-resource-id]:
+              aws.iam.role_policy_attachment.absent:
+                - name: "string"
+                - role_name: "string"
+                - policy_arn: "string"
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: sls
 
             resource_is_absent:
@@ -136,7 +154,7 @@ async def absent(
     result = dict(comment=(), old_state=None, new_state=None, name=name, result=True)
     try:
         before_ret = (
-            await hub.exec.aws.iam.role_policy_attachment.is_role_policy_attached(
+            await hub.tool.aws.iam.role_policy_attachment.is_role_policy_attached(
                 ctx, role_name=role_name, policy_arn=policy_arn
             )
         )
@@ -187,20 +205,16 @@ async def absent(
 
 
 async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
-    """
-
-    Describe the resource in a way that can be recreated/managed with the corresponding "present" function
-
+    """Describe the resource in a way that can be recreated/managed with the corresponding "present" function
 
     Lists the names of the attached managed policies of all IAM roles. If there are no managed policies attached
-     to the specified role, the operation returns an empty dict.
+    to the specified role, the operation returns an empty dict.
 
 
     Returns:
         Dict[str, Any]
 
     Examples:
-
         .. code-block:: bash
 
             $ idem describe aws.iam.role_policy_attachment
