@@ -249,7 +249,7 @@ async def present(
                 operation="DescribeCreateAccountStatus",
                 argument=["CreateAccountStatus.State"],
                 acceptors=acceptors,
-                client=hub.tool.boto3.client.get_client(ctx, SERVICE),
+                client=await hub.tool.boto3.client.get_client(ctx, SERVICE),
                 matcher="path",
                 delay=10,
                 max_tries=10,
