@@ -82,7 +82,7 @@ async def present(
             attributes[key] = hub.tool.aws.sns.conversion_utils.standardise_json(value)
 
     if resource_id:
-        resource = hub.tool.boto3.resource.create(
+        resource = await hub.tool.boto3.resource.create(
             ctx, "sns", "Subscription", arn=resource_id
         )
         before = await hub.tool.boto3.resource.describe(resource)
@@ -167,7 +167,7 @@ async def present(
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif (not before) or resource_updated:
-            resource = hub.tool.boto3.resource.create(
+            resource = await hub.tool.boto3.resource.create(
                 ctx, "sns", "Subscription", arn=resource_id
             )
             after = await hub.tool.boto3.resource.describe(resource)
@@ -221,7 +221,7 @@ async def absent(hub, ctx, name: str, resource_id: str) -> Dict[str, Any]:
         return result
     for subscription in ret["ret"]["Subscriptions"]:
         if subscription.get("SubscriptionArn") == resource_id:
-            resource = hub.tool.boto3.resource.create(
+            resource = await hub.tool.boto3.resource.create(
                 ctx, "sns", "Subscription", arn=resource_id
             )
             before = await hub.tool.boto3.resource.describe(resource)
@@ -285,7 +285,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         if resource_id == "Deleted" or resource_id == "PendingConfirmation":
             continue
         # Attributes are not present in the return value of list_subscriptions
-        resource = hub.tool.boto3.resource.create(
+        resource = await hub.tool.boto3.resource.create(
             ctx, "sns", "Subscription", arn=resource_id
         )
         raw_resource = await hub.tool.boto3.resource.describe(resource)
