@@ -211,7 +211,7 @@ async def update_db_cluster(
                 operation="DescribeDBClusters",
                 argument=["DBClusters[].Status"],
                 acceptors=update_waiter_acceptors,
-                client=hub.tool.boto3.client.get_client(ctx, "neptune"),
+                client=await hub.tool.boto3.client.get_client(ctx, "neptune"),
             )
             try:
                 await hub.tool.boto3.client.wait(
