@@ -26,6 +26,31 @@ def convert_raw_bucket_notification_to_present(
     return translated_resource
 
 
+def convert_raw_bucket_logging_to_present(
+    hub, ctx, raw_resource: Dict[str, Any], bucket_name: str
+) -> Dict[str, Any]:
+    """
+    Convert the s3 bucket logging configurations response to a common format
+
+    Args:
+        raw_resource: Dictionary of s3 bucket logging configurations
+        bucket_name: Name of the bucket on which logging needs to be configured.
+
+    Returns:
+        A dictionary of s3 bucket logging configurations
+    """
+    translated_resource = {}
+    raw_resource.pop("ResponseMetadata", None)
+
+    if raw_resource:
+        translated_resource["name"] = bucket_name
+        translated_resource["resource_id"] = bucket_name
+        translated_resource["bucket_logging_status"] = json.loads(
+            json.dumps(raw_resource)
+        )
+    return translated_resource
+
+
 async def convert_raw_s3_to_present(
     hub, ctx, idem_resource_name: str = None
 ) -> Dict[str, Any]:
@@ -42,6 +67,7 @@ async def convert_raw_s3_to_present(
         "name": idem_resource_name,
         "resource_id": idem_resource_name,
     }
+    bucket_acl: dict = {}
     result = dict(comment=(), result=True, ret=None)
     ret = await hub.exec.boto3.client.s3.get_object_lock_configuration(
         ctx, Bucket=idem_resource_name
@@ -106,18 +132,47 @@ async def convert_raw_s3_to_present(
             result["result"] = False
             return result
     # checking first element in grants because for no permissions API returns empty array
+    full_control = ""
+    read = ""
+    read_acp = ""
+    write = ""
+    write_acp = ""
+
     if ret["result"] and ret["ret"]["Grants"][0]["Permission"]:
-        if ret["ret"]["Grants"][0]["Permission"] == "FULL_CONTROL":
-            resource_translated["grant_full_control"] = "FULL_CONTROL"
-        elif ret["ret"]["Grants"][0]["Permission"] == "READ":
-            resource_translated["grant_read"] = "READ"
-        elif ret["ret"]["Grants"][0]["Permission"] == "READ_ACP":
-            resource_translated["grant_read_acp"] = "READ_ACP"
-        elif ret["ret"]["Grants"][0]["Permission"] == "WRITE":
-            resource_translated["grant_write"] = "WRITE"
-        else:
-            resource_translated["grant_write_acp"] = "WRITE_ACP"
-        resource_translated["acl"] = ret["ret"]["Grants"]
+        for grant in ret["ret"]["Grants"]:
+            if grant["Permission"]:
+                grantee = grant["Grantee"]
+                if grant["Permission"] == "FULL_CONTROL":
+                    full_control = hub.tool.aws.s3.s3_utils.get_grantee_payload(
+                        full_control, grantee
+                    )
+                elif grant["Permission"] == "READ":
+                    read = hub.tool.aws.s3.s3_utils.get_grantee_payload(read, grantee)
+                elif grant["Permission"] == "READ_ACP":
+                    read_acp = hub.tool.aws.s3.s3_utils.get_grantee_payload(
+                        read_acp, grantee
+                    )
+                elif grant["Permission"] == "WRITE":
+                    write = hub.tool.aws.s3.s3_utils.get_grantee_payload(write, grantee)
+                elif grant["Permission"] == "WRITE_ACP":
+                    write_acp = hub.tool.aws.s3.s3_utils.get_grantee_payload(
+                        write_acp, grantee
+                    )
+
+    if full_control:
+        resource_translated["full_control"] = full_control
+
+    if read:
+        resource_translated["read"] = read
+
+    if read_acp:
+        resource_translated["read_acp"] = read_acp
+
+    if write:
+        resource_translated["write"] = write
+
+    if write_acp:
+        resource_translated["write_acp"] = write_acp
 
     ret = await hub.exec.boto3.client.s3.get_bucket_tagging(
         ctx, Bucket=idem_resource_name
@@ -176,3 +231,54 @@ def convert_raw_bucket_policy_to_present(
         translated_resource["bucket"] = bucket
         translated_resource["policy"] = raw_resource["Policy"]
     return translated_resource
+
+
+def convert_raw_bucket_replication_to_present(
+    hub, ctx, raw_resource: Dict[str, Any], bucket_name: str
+) -> Dict[str, Any]:
+    """
+    Convert the s3 bucket replication configurations response to a common format
+
+    Args:
+        raw_resource: Dictionary of s3 bucket replication configurations
+        bucket_name: Name of the bucket on which replication needs to be configured.
+
+    Returns:
+        A dictionary of s3 bucket replication configurations
+    """
+    translated_resource = {}
+    raw_resource.pop("ResponseMetadata", None)
+
+    if raw_resource:
+        translated_resource["name"] = bucket_name
+        translated_resource["resource_id"] = bucket_name
+        translated_resource["role"] = raw_resource["ReplicationConfiguration"]["Role"]
+        translated_resource["rules"] = raw_resource["ReplicationConfiguration"]["Rules"]
+    return translated_resource
+
+
+def convert_raw_acl_policy_to_present(
+    hub, raw_resource: Dict[str, Any], bucket_name: str
+) -> Dict[str, Any]:
+    """
+    Util function to convert the s3 bucket policy response to a common format
+
+    Args:
+        hub: required for functions in hub
+        raw_resource (Dict): S3 bucket policy response
+        bucket_name(str): Name of the bucket on which policy needs to be configured.
+
+    Returns:
+        A dictionary of s3 bucket notification configurations
+    """
+    translated_resource = {}
+    raw_resource.pop("ResponseMetadata", None)
+
+    if raw_resource:
+        translated_resource["resource_id"] = bucket_name
+        translated_resource["name"] = bucket_name
+        translated_resource["access_control_policy"] = json.loads(
+            json.dumps(raw_resource)
+        )
+
+    return translated_resource
