@@ -5,6 +5,20 @@ from typing import Dict
 from typing import List
 
 
+"""
+ATTENTION: Functions in this util file are highly controversial and we don't encourage use any of these functions.
+1. These functions give developers a misconception that they are suitable for comparing certain data structure.
+In reality, they are not. They all have limitations and only work on certain scope of data structures. Data structure
+such as List and Dict can contain nested data structures and these functions will certainly not do the job well on
+nested data structure.
+2. There are mature modules if we have to compare two complex data structure, for example, dict_tool, deepdiff.
+The functions here are re-inventing the wheel.
+
+Hence, think about twice before you decide to use any of the following functions. There should be no new util function
+added to this file and the existing functions should be deprecated at some point.
+"""
+
+
 def are_lists_identical(hub, list1: List, list2: List) -> bool:
     """
     Compare two lists and logs the difference.
